<?php

namespace App\Http\Middleware;

use Closure;
use App\Models\Admin;
use App\Models\Subscription;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Symfony\Component\HttpFoundation\Response;

class CheckMaxCreate
{
    /**
     * Handle an incoming request.
     *
     * @param \Illuminate\Http\Request $request
     * @param \Closure(\Illuminate\Http\Request): (\Symfony\Component\HttpFoundation\Response) $next
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function handle(Request $request, Closure $next): Response
    {
        if (Auth::check()) {

            $user = Auth::user();

            $adminId = getAdminIdByUserRole();
            $admin = Admin::findOrFail($adminId);
            $subscription = Subscription::where(['user_id' => $admin->user_id, 'status' => 'active'])->first();
            $projects = $admin->projects()->count();
            $users = $admin->teamMembers()->count();
            $clients = $admin->clients()->count();
            $workspaces = $admin->workspaces()->count();
            $subscriptionFeatures =  json_decode($subscription->features, true);
           
            $currentRoute = $request->route()->getName();

            // $projects = 
           
            if (str_contains($currentRoute, '.create')) {

                $resource = explode('.', $currentRoute)[0];

                switch ($resource) {
                    case 'clients':
                        if ($clients >= $subscriptionFeatures['max_clients']) {
                            return redirect()->back()->with('error', 'You have reached the maximum limit for creating clients.');
                        }
                        break;
                    case 'projects':
                        if ($projects >= $subscriptionFeatures['max_projects']) {
                            return redirect()->back()->with('error', 'You have reached the maximum limit for creating projects.');
                        }
                        break;
                    case 'users':
                        if ($users >= $subscriptionFeatures['max_team_members']) {
                            return redirect()->back()->with('error', 'You have reached the maximum limit for creating team members.');
                        }
                        break;
                    case 'workspaces':
                        if ($workspaces >= $subscriptionFeatures['max_workspaces']) {
                            return redirect()->back()->with('error', 'You have reached the maximum limit for creating workspaces.');
                        }
                        break;
                }
            }
        }
        return $next($request);
    }
}
